nagios_host 'journals.ashs.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'HORT',
		'address' => 'journals.ashs.org',
		'contact_groups' => 'cs_escalation,hort',
		'notes' => 'HORT Live Site',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/HORT/pages/510033976/Server+Setup+-+American+Society+for+Horticultural+Science+HORT+ASHS'
end
nagios_host 'admin.ashs.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'HORT',
		'address' => 'admin.ashs.org',
		'contact_groups' => 'cs_escalation,hort',
		'notes' => 'HORT Production Management Portal',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/HORT/pages/510033976/Server+Setup+-+American+Society+for+Horticultural+Science+HORT+ASHS'
end
nagios_host 'ams.ashs.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'HORT',
		'address' => 'ams.ashs.org',
		'contact_groups' => 'cs_escalation,hort',
		'notes' => 'HORT Production AMS',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/HORT/pages/510033976/Server+Setup+-+American+Society+for+Horticultural+Science+HORT+ASHS'
end
#------------------------------------------------------------------------------------
# HOMEPAGE
# checks the homepage of the live HORT site and checks for the string 'American Society for Horticultural Science'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'journals.ashs.org-Live Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ashs.org',
		'display_name' => 'Live Homepage',
		'check_command' => 'https_content_check_basic_auth!hort:hort2018!/!"American Society for Horticultural Science"!10!20!',
		'contact_groups' => 'cs_escalation,hort',
		'notes' => 'HORT Live Site',
		'notes_url' => 'https://journals.ashs.org'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 1)
# checks the homepage of the live hort site on the first web node and checks for the string 'American Society for Horticultural Science'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ashs.org-Live Homepage: web-2' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ashs.org',
		'display_name' => 'Live Homepage: web-2',
		'check_command' => 'https_content_check_basic_auth_single_node!hort:hort2018!/!"American Society for Horticultural Science"!10!20!hort-web-live2!web-2!',
		'contact_groups' => 'admins_email_only,hort',
		'notes' => 'HORT Live Site: web-2',
		'notes_url' => 'https://journals.ashs.org'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 2)
# checks the homepage of the live hort site on the sercond web node and checks for the string 'American Society for Horticultural Science'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ashs.org-Live Homepage: hort-web-1' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ashs.org',
		'display_name' => 'Live Homepage: hort-web-1',
		'check_command' => 'https_content_check_basic_auth_single_node!hort:hort2018!/!"American Society for Horticultural Science"!10!20!hort-web-live1!hort-web-1!',
		'contact_groups' => 'admins_email_only,hort',
		'notes' => 'HORT Live Site: hort-web-1',
		'notes_url' => 'https://journals.ashs.org'
end
#------------------------------------------------------------------------------------
# SEARCH
# Checks the search of the live HORT site and checks for the string 'American Society for Horticultural Science'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'journals.ashs.org-Live Search' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ashs.org',
		'display_name' => 'Live Search',
		'check_command' => 'https_content_check_basic_auth!hort:hort2018!/browse!browse!10!20!',
		'contact_groups' => 'cs_escalation,hort',
		'notes' => 'HORT Live Site',
		'notes_url' => 'https://journals.ashs.org/browse'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 1)
# Checks the search of the live hort site on the first web node and checks for the string 'American Society for Horticultural Science'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ashs.org-Live Search: web-2' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ashs.org',
		'display_name' => 'Live search: web-2',
		'check_command' => 'https_content_check_basic_auth_single_node!hort:hort2018!/browse!browse!10!20!hort-web-live2!web-2!',
		'contact_groups' => 'admins_email_only,hort',
		'notes' => 'HORT Live Site: web-2',
		'notes_url' => 'https://journals.ashs.org/browse'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 2)
# Checks the search of the live hort site on the second web node and checks for the string 'American Society for Horticultural Science'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ashs.org-Live search: hort-web-1' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ashs.org',
		'display_name' => 'Live search: web-2',
		'check_command' => 'https_content_check_basic_auth_single_node!hort:hort2018!/browse!browse!10!20!hort-web-live1!hort-web-1!',
		'contact_groups' => 'admins_email_only,hort',
		'notes' => 'HORT Live Site: hort-web-1',
		'notes_url' => 'https://journals.ashs.org/browse'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW
# checks the content view of the live HORT site and checks for the string 'American Society for Horticultural Science'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'journals.ashs.org-Live content view' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ashs.org',
		'display_name' => 'Live content view',
		'check_command' => 'https_content_check_basic_auth!hort:hort2018!/horttech/view/journals/horttech/28/5/article-p651.xml!Economic!10!20!',
		'contact_groups' => 'cs_escalation,hort',
		'notes' => 'HORT Live Site',
		'notes_url' => 'https://journals.ashs.org/horttech/view/journals/horttech/28/5/article-p651.xml'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 1)
# checks the content view of the live hort site on the first web node and checks for the string 'American Society for Horticultural Science'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ashs.org-Live content view: web-2' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ashs.org',
		'display_name' => 'Live content view: web-2',
		'check_command' => 'https_content_check_basic_auth_single_node!hort:hort2018!/horttech/view/journals/horttech/28/5/article-p651.xml!Economic!10!20!hort-web-live2!web-2!',
		'contact_groups' => 'admins_email_only,hort',
		'notes' => 'HORT Live Site: web-2',
		'notes_url' => 'https://journals.ashs.org/horttech/view/journals/horttech/28/5/article-p651.xml'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 2)
# checks the content view of the live hort site on the sedmond web node and checks for the string 'American Society for Horticultural Science'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ashs.org-Live content view: hort-web-1' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ashs.org',
		'display_name' => 'Live content view: hort-web-1',
		'check_command' => 'https_content_check_basic_auth_single_node!hort:hort2018!/horttech/view/journals/horttech/28/5/article-p651.xml!Economic!10!20!hort-web-live1!hort-web-1!',
		'contact_groups' => 'admins_email_only,hort',
		'notes' => 'HORT Live Site: hort-web-1',
		'notes_url' => 'https://journals.ashs.org/horttech/view/journals/horttech/28/5/article-p651.xml'
end
#------------------------------------------------------------------------------------
# LOADER
# Checks a loader login page and looks for the string 'Login' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ashs.org-Production Loader' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'admin.ashs.org',
		'display_name' => 'Production Loader',
		'check_command' => 'check_loader_auth!admin.ashs.org!/login!hort:hort2018!"ASHS Production Management Portal"!20!10',
		'contact_groups' => 'admins_email_only,hort',
		'notes' => 'HORT Live Loader',
		'notes_url' => 'https://admin.ashs.org/login'
end
#------------------------------------------------------------------------------------
# STAGING
# Checks the staging site homepage and looks for the string 'American Society for Horticultural Science' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ashs.org-Staging Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ashs.org',
		'display_name' => 'Staging Homepage',
		'check_command' => 'check_staging_auth!journals-staging.ashs.org!hort:hort2018!"American Society for Horticultural Science"!20!10',
		'contact_groups' => 'admins_email_only,hort',
		'notes' => 'HORT Staging Site',
		'notes_url' => 'https//journals-staging.ashs.org'
end
#------------------------------------------------------------------------------------
# AMX
# Checks the production amx homepage and looks for the string 'AMS' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ashs.org-Production AMX' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ams.ashs.org',
		'display_name' => 'Production AMX',
		'check_command' => 'check_loader_auth!ams.ashs.org!/login!hort:hort2018!AMS!20!10',
		'contact_groups' => 'admins_email_only,hort',
		'notes' => 'HORT AMX',
		'notes_url' => 'https://ams.ashs.org/login'
end
#------------------------------------------------------------------------------------
# FAIL OPEN
# Checks the production homepage and makes sure we're not in fail open by checking
# that the string "Provisional Account" is NOT in the page.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ashs.org-Live Site Fail Open' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ashs.org',
		'display_name' => 'Live Site Fail Open',
		'check_command' => 'http_negate_content_check_basic_auth!journals.ashs.org!hort:hort2018!"provisional account"',
		'contact_groups' => 'admins_email_only,hort',
		'notes' => 'HORT Live Site Failopen',
		'notes_url' => 'https://journals.ashs.org/'
end
