nagios_host 'journals.humankinetics.com' do
	options 'use' => 'noping-host-https',
		'alias' => 'hk',
		'address' => 'journals.humankinetics.com',
		'contact_groups' => 'cs_escalation,human-kinetics',
		'notes' => 'Human Kinetics Live Site',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/HK/pages/594608192/Human+Kinetics+HK+-+Server+Setup'
end
#------------------------------------------------------------------------------------
# HOMEPAGE
# Checks the homepage of the live Human Kinetics site and checks for the string 'Human Kinetics'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'journals.humankinetics.com-Live Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.humankinetics.com',
		'display_name' => 'Live Homepage',
		'check_command' => 'https_content_check_basic_auth!hk:hk2018!/!"Human Kinetics"!10!20!',
		'notes' => 'Human Kinetics Live Site',
		'notes_url' => 'https://journals.humankinetics.com/'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 1)
# Checks the homepage of the live Human Kinetics site on the first web node and checks for the string 'Human Kinetics'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.humankinetics.com-Live Homepage: hk-web-2' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.humankinetics.com',
		'display_name' => 'Live Homepage: hk-web-2',
		'check_command' => 'https_content_check_basic_auth_single_node!hk:hk2018!/!"Human Kinetics"!10!20!hk-web-live2!hk-web-2!',
		'contact_groups' => 'admins_email_only,human-kinetics',
		'notes' => 'Human Kinetics Live Site: hk-web-2',
		'notes_url' => 'https://journals.humankinetics.com/'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 2)
# Checks the homepage of the live Human Kinetics site on the second web node and checks for the string 'Human Kinetics'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.humankinetics.com-Live Homepage: hk-web-3' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.humankinetics.com',
		'display_name' => 'Live Homepage: hk-web-3',
		'check_command' => 'https_content_check_basic_auth_single_node!hk:hk2018!/!"Human Kinetics"!10!20!hk-web-live3!hk-web-3!',
		'contact_groups' => 'admins_email_only,human-kinetics',
		'notes' => 'Human Kinetics Live Site: hk-web-3',
		'notes_url' => 'https://journals.humankinetics.com/'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 4 BOT)
# Checks the homepage of the live Human Kinetics site on the second web node and checks for the string 'Human Kinetics'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.humankinetics.com-Live Homepage: hk-webbot-1' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.humankinetics.com',
		'display_name' => 'Live Homepage: hk-webbot-1',
		'check_command' => 'https_content_check_basic_auth_single_node_bot!hk:hk2018!/!"Human Kinetics"!10!20!hk-webbot-1!hk-webbot-1!',
		'contact_groups' => 'admins_email_only,human-kinetics',
		'notes' => 'Human Kinetics Live Site: hk-webbot-1',
		'notes_url' => 'https://journals.humankinetics.com/'
end
#------------------------------------------------------------------------------------
# SEARCH
# Checks the search page of the live Human Kinetics site and checks for the string 'Browse'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'journals.humankinetics.com-Live Search' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.humankinetics.com',
		'display_name' => 'Live Search',
		'check_command' => 'https_content_check_basic_auth!hk:hk2018!/browse?level=parent!Browse!10!20!',
		'notes' => 'Human Kinetics Live Site',
		'notes_url' => 'https://journals.humankinetics.com/browse?level=parent'
end
#------------------------------------------------------------------------------------
# VIEW
# Checks a content view page of the live hk site for the book at the URL
# /view/journals/ijsnem/ijsnem-overview.xml.  The title of this journal is "International Journal of Sport Nutrition and Exercise Metabolism".  This check
# looks for the string 'Metabolism' in the response.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'journals.humankinetics.com-Live Content View' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.humankinetics.com',
		'display_name' => 'Live Content View',
		'check_command' => 'https_content_check_basic_auth!hk:hk2018!/view/journals/ijsnem/ijsnem-overview.xml!Metabolism!10!20!',
		'notes' => 'Human Kinetics Live Site',
		'notes_url' => 'https://journals.humankinetics.com/view/journals/ijsnem/ijsnem-overview.xml'
end
#------------------------------------------------------------------------------------
# LOADER
# Checks a loader login page and looks for the string 'Login' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.humankinetics.com-Production Loader' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.humankinetics.com',
		'display_name' => 'Production Loader',
		'check_command' => 'check_loader_auth!admin-journals.humankinetics.com!/login!hk:hk2018!"HK Production Management Portal"!20!10',
		'contact_groups' => 'admins_email_only,human-kinetics',
		'notes' => 'Human Kinetics Live Loader',
		'notes_url' => 'https://admin-journals.humankinetics.com/login'
end
#------------------------------------------------------------------------------------
# STAGING
# Checks the staging site homepage and looks for the string 'Human Kinetics' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.humankinetics.com-Staging Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.humankinetics.com',
		'display_name' => 'Staging Homepage',
		'check_command' => 'check_staging_auth!journals-staging.humankinetics.com!hk:hk2018!"Human Kinetics"!20!10',
		'contact_groups' => 'admins_email_only,human-kinetics',
		'notes' => 'Human Kinetics Staging Site',
		'notes_url' => 'https://hk.hk-staging.irl.pubfactory.com/'
end
#------------------------------------------------------------------------------------
# AMX
# Checks the production amx homepage and looks for the string 'Human Kinetics' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.humankinetics.com-Production AMX' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.humankinetics.com',
		'display_name' => 'Production AMX',
		'check_command' => 'check_loader_auth!ams.humankinetics.com!/login!hk:hk2018!AMS!20!10',
		'contact_groups' => 'admins_email_only,human-kinetics',
		'notes' => 'Human Kinetics AMX',
		'notes_url' => 'https://ams.humankinetics.com/login'
end
#------------------------------------------------------------------------------------
# FAIL OPEN
# Checks the production homepage and makes sure we're not in fail open by checking
# that the string "Provisional Account" is NOT in the page.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.humankinetics.com-Live Site Fail Open' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.humankinetics.com',
		'display_name' => 'Live Site Fail Open',
		'check_command' => 'http_negate_content_check_basic_auth!journals.humankinetics.com!hk:hk2018!"provisional account"',
		'contact_groups' => 'admins_email_only,human-kinetics',
		'notes' => 'Human Kinetics Live Site Failopen',
		'notes_url' => 'https://journals.humankinetics.com/'
end
